<?php
/**
 * darkel functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package darkel
 */
if ( ! function_exists( 'darkel_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function darkel_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on darkel, use a find and replace
		 * to change 'darkel_lite' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'darkel_lite', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		 // Image sizes
    	 add_image_size('darkel_blog_770x420', 770, 420, true);
    	 add_image_size('darkel_recent_post_90x80', 90, 80, true);
    	 add_image_size('event_details_870_450', 870, 450, true); 
    	 add_image_size('event_box_150_150', 150, 150, true); 
		/**
		* Constants
		* Defining default asset paths
		*/
		define('darkel_DIR_CSS', get_template_directory_uri().'/assets/css');
		define('darkel_DIR_JS', get_template_directory_uri().'/assets/js');
		define('darkel_DIR_VEND', get_template_directory_uri().'/assets/vendors');
		define('darkel_DIR_IMG', get_template_directory_uri().'/assets/img');
		define('darkel_DIR_FONT', get_template_directory_uri().'/assets/fonts');
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'main_menu' => esc_html__( 'Primary', 'darkel_lite' ),
		) );
		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );
		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'darkel_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'darkel_setup' );
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function darkel_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'darkel_content_width', 640 );
}
add_action( 'after_setup_theme', 'darkel_content_width', 0 );
/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function darkel_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Widget Sidebar', 'darkel_lite' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'darkel_lite' ),
		'before_widget' => '<div id="%1$s" class="single_sidebar">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Sidebar', 'darkel_lite' ),
		'id'            => 'footer_sidebar',
		'description'   => esc_html__( 'Add Footer widgets here.', 'darkel_lite' ),
		'before_widget' => '<div id="%1$s" class="col-lg-3 col-sm-6 single_feature_footer">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'darkel_widgets_init' );
/**
 * Enqueue scripts and styles.
 */
function darkel_scripts() {
	wp_enqueue_style( 'darkel-style', get_stylesheet_uri() );

	wp_enqueue_script( 'darkel-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'darkel-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'darkel_scripts' );
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/enqueue.php';
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/demo_config.php';


/**
 * Welcome Function.
 */
require get_template_directory() . '/inc/welcome/welcome-config.php';

/**
 * Implement the Nav Walker
 */
require get_template_directory() . '/inc/navwalker.php';
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/functions.php';
/**
 * Plugin Activation
 */
require get_template_directory() . '/inc/plugin_activation.php';
/**
 * Options Freamwork
 */
require get_template_directory() . '/inc/options/opt-config.php';
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';
/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';
/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';
/**
 * Breadcrumbs additions.
 */
require get_template_directory() . '/inc/darkel-breadcrumbs.php';
/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

