<?php 
// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}
/**
 *
 * @Packge      darkel
 * @Author      Droit Themes
 * @Author URL  https//www.Dritthemes.com
 * @version     1.0
 *
 */

if ( ! function_exists( 'darkel_breadcrumbs' ) ) {
    function darkel_breadcrumbs( $args = array() ) {
        if ( is_front_page() ) {
            return;
        }
        if ( get_theme_mod( 'ct_ignite_show_breadcrumbs_setting' ) == 'no' ) {
            return;
        }
        global $post;
        $defaults  = array(
            'breadcrumbs_id'      => '',
            'breadcrumbs_classes' => esc_html( 'breadcrumb' ),
            'home_title'          => esc_html__( 'Home', 'darkel_lite' )
        );
        $args      = apply_filters( 'darkel_breadcrumbs_args', wp_parse_args( $args, $defaults ) );
                
        $args_el = array();
        
        if( $args['breadcrumbs_id'] ){
            
            $args_el[] =  'id="'.esc_attr( $args['breadcrumbs_id'] ).'"';
        }
        
        if( $args['breadcrumbs_classes'] ){
            
            $args_el[] =  'class="'.esc_attr( $args['breadcrumbs_classes'] ).'"';
            
        }
        
        /*
        * Begin Markup  
        */
        
        // Open the breadcrumbs

        $html = '<ul class="breadcrumb_iner_link">';
        // Add Homepage link (always present)
        $html .= '<li><a href="' . esc_url( get_home_url('/') ) . '" title="' . esc_attr( $args['home_title'] ) . '">'.esc_html__( 'Home', 'darkel_lite' ).' </a></li>';
        // Post
        if ( is_singular( 'post' ) ) {
            $category = get_the_category();
            $category_values = array_values( $category );
            $last_category = end( $category_values );
            $cat_parents = rtrim( get_category_parents( $last_category->term_id, true, '' ), ',' );
            $cat_parents = explode( ',', $cat_parents );
            foreach ( $cat_parents as $parent ) {
                $html .= wp_kses_post( '<li>'.$parent.'</li>' );         
            }
            $html .= '<li title="' . esc_attr( get_the_title() ) . ' active" aria-current="page">' . esc_html( get_the_title() ) . '</li>';
        } elseif ( is_singular( 'page' ) ) {
            if ( $post->post_parent ) {
                $parents = get_post_ancestors( $post->ID );
                $parents = array_reverse( $parents );
                foreach ( $parents as $parent ) {
                    $html .= '<li><a href="' . esc_url( get_permalink( $parent ) ) . '" title="' . esc_attr( get_the_title( $parent ) ) . '">' . esc_html( get_the_title( $parent ) ) . '</li></a>';
                }
            }
            $html .= '<li aria-current="page">'.esc_html( get_the_title() ).'</li>';
        } elseif ( is_singular( 'attachment' ) ) {
            $parent_id        = $post->post_parent;
            $parent_title     = get_the_title( $parent_id );
            $parent_permalink = esc_url( get_permalink( $parent_id ) );
            $html .= '<li aria-current="page"><a href="' . esc_url( $parent_permalink ) . '" title="' . esc_attr( $parent_title ) . '">' . esc_attr( $parent_title ) . '</a></li>';
            $html .= '<span class="s-text17" title="' . esc_attr( get_the_title() ) . '"> ' . esc_html( get_the_title() ) . '</span>';
        } elseif ( is_singular() ) {
            $post_type         = get_post_type();
            $post_type_object  = get_post_type_object( $post_type );
            $post_type_archive = get_post_type_archive_link( $post_type );
            $html .= '<li aria-current="page"><a href="' . esc_url( $post_type_archive ) . '" title="' . esc_attr( $post_type_object->labels->name ) . '">' . esc_attr( $post_type_object->labels->name ) . ' /</a></li>';
            $html .= '<span class="s-text17 bread-' . $post->ID . '" title="' . $post->post_title . '">' . $post->post_title . '</span>';
			
        } elseif ( is_category() ) {
            $parent = get_queried_object()->category_parent;
            if ( $parent !== 0 ) {
                $parent_category = get_category( $parent );
                $category_link   = get_category_link( $parent );
                $html .= '<li aria-current="page"><a href="' . esc_url( $category_link ) . '" title="' . esc_attr( $parent_category->name ) . '">' . esc_attr( $parent_category->name ) . '</a></li>';
            }
            $html .= '<li title="' . $post->ID . '">' . single_cat_title( '', false ) . '</li>';
        } elseif ( is_tag() ) {
            $html .= '<li aria-current="page">' . single_tag_title( '', false ) . '</li>';
        } elseif ( is_author() ) {
            $html .= '<li aria-current="page">' . get_queried_object()->display_name . '</li>';
        } elseif ( is_day() ) {
            $html .= '<li aria-current="page">' . get_the_date() . '</li>';
        } elseif ( is_month() ) {
            $html .= '<li aria-current="page">' . get_the_date( 'F Y' ) . '</li>';
        } elseif ( is_year() ) {
            $html .= '<li aria-current="page">' . get_the_date( 'Y' ) . '</li>';
        } elseif ( is_archive() ) {			
            $custom_tax_name = get_queried_object()->name;
            $html .= '<li aria-current="page">' . esc_attr( $custom_tax_name ) . '</li>';
        } elseif ( is_search() ) {
            $html .= '<li aria-current="page">'.esc_html__('Search results for:','darkel_lite') . get_search_query() . '</li>';
        } elseif ( is_404() ) {
            $html .= '<li aria-current="page">' . esc_html__( 'Error 404', 'darkel_lite' ) . '</li>';
        } elseif ( is_home() ) {
            $html .= '<li aria-current="page">' . get_the_title( get_option( 'page_for_posts' ) ) . '</li>';
        }
        $html .= '</ul>';
        $html = apply_filters( 'darkel_breadcrumbs_filter', $html );
		
		echo wp_kses_post( $html );	
	
        
    }
}
