<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package darkel
 */

// Pagination
function darkel_pagination() {
    the_posts_pagination(array(
        'screen_reader_text' => ' ',
        'prev_text'          => '<i class="arrow_left"></i>',
        'next_text'          => '<i class="arrow_right"></i>'
    ));
}

// Metabox author

function darkel_post_author_metabox(){ ?>
    <div class="post_author section_bg blog_page_single_item">
    <a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>">
    <?php echo get_avatar(get_the_author_meta('ID'), 120, array('rating' => get_option('avatar_rating')), '', array('class' => 'img-circle')) ?>
    </a>
    <div class="author_details">
        <h5><?php echo get_the_author_meta('display_name'); ?> <span><?php echo get_the_author_meta('user_nicename'); ?></span></h5>
        <p><?php echo get_the_author_meta('description'); ?></p>
    </div>
</div>
<?php } 


// Comment list
function darkel_comments($comment, $args, $depth){
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    ?>
    <li <?php comment_class( $args['has_children'] ? 'post_comment has_children' :'post_comment') ?> id="comment-<?php comment_ID() ?>">
        <div class="media">
                <?php
                if(get_avatar($comment)) {
                    echo get_avatar($comment, 70, null, null, array('class'=> 'admin_img'));
                }
                ?>
                <div class="media-body">
                    <div class="admin_tittle">
                        <h5><?php comment_author(); ?> <span>
                            <?php printf( _x( '%s ago', '%s = human-readable time difference', 'darkel_lite' ), human_time_diff( get_comment_time( 'U' ), current_time( 'timestamp' ) ) ); ?></span></h5>
                    </div>
                    <p><?php comment_text(); ?></p>
                    <i class="arrow_back"></i>&nbsp;<?php comment_reply_link(array_merge( $args, array('reply_text' => 'Reply', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?>
                    
                </div>
        </div>
    </li>
    <?php
}
// add class comment reply link
add_filter('comment_reply_link', 'eiser_replace_reply_link_class');
function eiser_replace_reply_link_class( $class ) {
	$class = str_replace("class='comment-reply-link", "class='btn-reply reply_link comment-reply-link ", $class);
	return $class;
}


/**
 * Moving the comments text field to bottom
 */
function darkel_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields[ 'comment' ];
    unset( $fields[ 'comment' ] );
    $fields[ 'comment' ] = $comment_field;
    return $fields;
}

add_filter( 'comment_form_fields', 'darkel_move_comment_field_to_bottom' );



// Social Links
function darkel_social_links() {
    $opt = get_option('darkel_opt');
    ?>
    <?php if(!empty($opt['facebook'])) { ?>
        <a href="<?php echo esc_url($opt['facebook']); ?>"><i class="social_facebook"></i></a>
    <?php } ?>
    <?php if(!empty($opt['twitter'])) { ?>
        <a href="<?php echo esc_url($opt['twitter']); ?>"><i class="social_twitter" ></i></a>
    <?php } ?>
    <?php if(!empty($opt['vimeo'])) { ?>
        <a href="<?php echo esc_url($opt['vimeo']); ?>"><i class="social_vimeo"></i></a>
    <?php } ?>
    <?php if(!empty($opt['instagram'])) { ?>
        <a href="<?php echo esc_url($opt['instagram']); ?>"><i class="social_instagram"></i></a>
    <?php } ?>
    <?php if(!empty($opt['linkedin'])) { ?>
        <a href="<?php echo esc_url($opt['linkedin']); ?>"><i class="social_linkedin" ></i></a>
    <?php } ?>
    <?php if(!empty($opt['youtube'])) { ?>
        <a href="<?php echo esc_url($opt['youtube']); ?>"><i class="social_youtube" ></i></a>
    <?php } ?>
    <?php if(!empty($opt['dribbble'])) { ?>
        <a href="<?php echo esc_url($opt['dribbble']); ?>"><i class="social_dribbble" ></i></a>
    <?php } ?>
    <?php
}

// Search form
function darkel_search_form($is_button=true) {
    ?>
    <div class="darkel-search">
        <form class="form-wrapper" action="<?php echo esc_url(home_url('/')); ?>" _lpchecked="1">
            <input type="text" id="search" placeholder="<?php esc_attr_e('Search ...', 'darkel_lite'); ?>" name="s">
            <button type="submit" class="btn"><i class="fa fa-search"></i></button>
        </form>
        <?php if($is_button==true) { ?>
        <a href="<?php echo esc_url(home_url('/')); ?>" class="home_btn"> <?php esc_html_e('Back to home Page', 'darkel_lite'); ?> </a>
        <?php } ?>
    </div>
    <?php
}


// Day link to archive page
function darkel_day_link() {
    $archive_year   = get_the_time('Y');
    $archive_month  = get_the_time('m');
    $archive_day    = get_the_time('d');
    echo get_day_link( $archive_year, $archive_month, $archive_day);
}


// Limit latter
function darkel_limit_latter($string, $limit_length, $suffix = '...') {
    if (strlen($string) > $limit_length) {
        echo strip_shortcodes(substr($string, 0, $limit_length) . $suffix);
    }
    else {
        echo strip_shortcodes(esc_html($string));
    }
}


// Get comment count text
function darkel_comment_count($post_id, $no_comments = 'No Comments') {
    $comments_number = get_comments_number($post_id);
    if($comments_number == 0) {
        $comment_text = esc_html__('No Comment', 'darkel_lite');
    }elseif($comments_number == 1) {
        $comment_text = esc_html__('1 Comment', 'darkel_lite');
    }elseif($comments_number > 1) {
        $comment_text = $comments_number.esc_html__(' Comments', 'darkel_lite');
    }
    echo esc_html($comment_text);
}


// Post's excerpt text
function darkel_excerpt($redux_opt, $settings_key, $echo = true) {
    $opt = get_option($redux_opt);
    $excerpt_limit = !empty($opt[$settings_key]) ? $opt[$settings_key] : 40;
    $excerpt = wp_trim_words(get_the_content(), $excerpt_limit, '');
    if($echo == true) {
        echo esc_html($excerpt);
    }else {
        return esc_html($excerpt);
    }
}



// Banner Title
function darkel_banner_title() {
    $opt = get_option('darkel_opt');
    if( is_404() ){
	    $title_404 = !empty($opt['error_heading']) ? $opt['error_heading'] : esc_html__('404', 'darkel_lite');
        echo esc_html( $title_404 );
    }
    elseif (is_home()) {
        $blog_title = !empty($opt['blog_title']) ? $opt['blog_title'] : esc_html__('Blog', 'darkel_lite');
        echo esc_html($blog_title);
    } elseif (is_page() || is_single()) {
        the_title();
    } elseif (is_category()) {
        single_cat_title();
    } elseif (is_archive()) {
        the_archive_title();
    } elseif (is_search()) {
        esc_html_e('Search result for: “', 'darkel_lite');
        echo get_search_query() . '”';
    } else {
        the_title();
    }

}





function darkel_banner_subtitle() {
    $opt = get_option('darkel_opt');

    if (is_home()) {
        $blog_subtitle = !empty($opt['blog_subtitle']) ? $opt['blog_subtitle'] : get_bloginfo('description');
        echo esc_html($blog_subtitle);
    }
    elseif (is_page() || is_single()) {
        if (has_excerpt()) {
            while (have_posts()) {
                the_post();
                echo nl2br(get_the_excerpt(get_the_ID()));
            }
        }
    }

}



/**
 * Get a specific html tag from content
 * @return a specific HTML tag from the loaded content
 */
function darkel_get_html_tag( $tag = 'blockquote', $content = '' ) {
    $dom = new DOMDocument();
    $dom->loadHTML($content);
    $divs = $dom->getElementsByTagName( $tag );
    $i = 0;
    foreach ($divs as $div) {
        if($i == 1) {
            break;
        }
        echo "<h4>{$div->nodeValue}</h4>";

        ++$i;
    }
}

/*===========================================
    Post Tags
=============================================*/
function educations_tags(){

	$tags = get_the_tags();
	$getTags = '';

	if( $tags ){
        $getTags .= '<div class="post_tag d-flex align-items-center"><h4>'. esc_html__( 'Tags: ', 'darkel_lite' ) .'</h4>';
		foreach( $tags as $tag ){
			$getTags .= '<a href="'.esc_url( get_tag_link( $tag->term_id ) ).'" class="btn_4">'.esc_html( $tag->name ).'</a>';
		}
        $getTags .= '</div>';
	}
	return $getTags;
}

/*=================================================
*   Add span into category list
===================================================*/
add_filter('wp_list_categories', 'cat_count_span');
function cat_count_span($links) {
	$links = str_replace('</a> (', '<span> (', $links);
	$links = str_replace(')', ')</span></a>', $links);
	return $links;
}

/*==================================================
     Add span to Archive 
====================================================*/
function archive_count_span($links) {
    $links = str_replace('</a>&nbsp;(', '<span class="archiveCount"> (', $links);
    $links = str_replace(')', ')</span></a>', $links);
    return $links;
}

add_filter('get_archives_link', 'archive_count_span');